pynata
------

Pynata is a collection of Python utilities, making development faster
by providing solutions to common, reoccurring tasks in development

All 3rd party dependencies are optional and have to be
installed separately where required.

### Installation & Usage

Python 3.5.2 or greater required

Install latest stable build
```
pip install -U pynata
```

Install latest development build from Gitlab
```
pip install git+https://gitlab.com/meister245/pynata.git@development
```

### Wiki

* Changelog: https://gitlab.com/meister245/pynata/wikis/Changelog

### Bug report

Found an issue with the library? Use one of the methods below for reporting

* Issue tracking: https://gitlab.com/meister245/pynata/issues
* Email: [incoming+meister245/pynata@incoming.gitlab.com](mailto:incoming+meister245/pynata@incoming.gitlab.com)
